<template>
  <div class="mod-config">
    <basic-container>
      <ctable
        :table="table"
        @handleSelectionChange="handleSelectionChange"
        @objectSpanMethod="objectSpanMethod(arguments)"
        :uploadInfo="uploadInfo"
        :isShowHide="true"
        :prelang="prelang"
        :options="options"
        :bottomOffset="125"
        :ajaxFun="ajaxFun"
        ref="tableTestTable"
      >
        <template #toolbar></template>
      </ctable>
      <!-- 弹窗, 新增 / 修改 -->
    </basic-container>
  </div>
</template>

<script>
import { fetchList, delObj } from '@/api/basic/part'
import { mapGetters } from 'vuex'
import ctable from '@/views/common/custom-table.vue'
import { remote } from '../../../api/admin/dict'

export default {
  data() {
    return {
      ajaxFun: fetchList,
      addOrUpdateVisible: false,
      multipleSelection: [],
      uploadInfo: {
        // 是否展示上传EXCEL以及对应的url
        isShow: false,
        url: ''
      },
      prelang: 'tableTestTable',
      options: {
        height: 300, // 默认高度-为了表头固定
        stripe: false, // 是否为斑马纹 table
        highlightCurrentRow: false, // 是否要高亮当前行
        border: true, // 是否有纵向边框
        lazy: false, // 是否需要懒加载
        fit: true, // 列的宽度是否自撑开
        multiSelect: true, //
        isRefresh: true,
        seqNo: true,
        isShowHide: true, // 是否显示显影按钮
        isSearch: false, // 高级查询按钮
        defaultOrderBy: { column: 'id', direction: 'desc' }
      },
      table: {
        total: 0,
        currentPage: 1,
        pageSize: 20,
        data: [],
        // 标题
        column: [
          // 名称
          {
            minWidth: '120',
            prop: 'partName',
            label: '名称',
            sort: true,
            isTrue: true,
            isEdit: false,
            isSearch: true,
            editInfoType: 'text'
          },
          // 零件类型
          {
            minWidth: '120',
            prop: 'materialType',
            label: '零件类型',
            sort: true,
            isTrue: true,
            isEdit: true,
            isSearch: true,
            editInfoType: 'select',
            formatter: this.getMaterialTypeType,
            editOptList: () => {
              return this.getMaterialTypeList()
            }
          },
          // 规格
          {
            minWidth: '140',
            prop: 'specs',
            label: '规格',
            sort: true,
            isTrue: true,
            isEdit: false,
            isSearch: true,
            editInfoType: 'text'
          },
          // 型号
          {
            minWidth: '140',
            prop: 'partModel',
            label: '型号',
            sort: true,
            isTrue: true,
            isEdit: true,
            isSearch: true,
            editInfoType: 'text'
          },
          // 电压等级
          {
            minWidth: '140',
            prop: 'voltageLevel',
            label: '电压等级',
            sort: true,
            isTrue: true,
            isEdit: false,
            isSearch: true,
            editInfoType: 'text'
          },
          // 特性代号1
          {
            minWidth: '140',
            prop: 'characteristic1',
            label: '特性代号1',
            sort: true,
            isTrue: true,
            isEdit: false,
            isSearch: true,
            editInfoType: 'text'
          }
        ],
        toolbar: [
          {
            text: '编辑',
            type: 'primary',
            barShow: true,
            fun: this.editRows
          },
          {
            text: '取消',
            type: 'primary',
            barShow: false,
            fun: this.cancelEditRows
          }
        ],
        operator: null,
        operatorConfig: null
      },
      materialTypeList: []
    }
  },
  components: {
    ctable
  },
  created() {
    this.getMaterialType('material_type')
  },
  computed: {
    ...mapGetters(['permissions'])
  },
  methods: {
    objectSpanMethod(data) {
      console.log('spanData', data)
      if (data[3] === 2) {
        if (data[2] % 2 === 0) {
          data[4]({
            rowspan: 2,
            colspan: 1
          })
        } else {
          data[4]({
            rowspan: 0,
            colspan: 0
          })
        }
      }
    },
    cancelEditRows() {
      const tableData = this.$refs.tableTestTable.getTableData()
      this.table.toolbar[0].barShow = true
      this.table.toolbar[1].barShow = false
      tableData.forEach((item) => {
        item.isRowEdit = false
      })
    },
    editRows() {
      if (this.multipleSelection.length > 0) {
        this.table.toolbar[0].barShow = false
        this.table.toolbar[1].barShow = true
        this.multipleSelection.forEach((item) => {
          item.isRowEdit = true
        })
      } else {
        this.$message.error('请选择需要编辑的行')
      }
    },
    // 获取数据列表
    getData() {
      this.$refs.tableTestTable.getDataList()
    },
    // 删除
    deleteHandle(row) {
      this.$confirm('是否确认零件名为:' + row.partName, '提示', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        closeOnClickModal: false,
        type: 'warning'
      })
        .then(function() {
          return delObj(row.id)
        })
        .then((data) => {
          this.$message.success('删除成功')
          this.getData()
        })
    },
    handleSelectionChange(val) {
      this.multipleSelection = val
    },
    getMaterialType(type) {
      remote(type).then((response) => {
        const code = response.data.code
        if (code === 0) {
          const _data = response.data.data
          this.materialTypeList = _data
        }
      })
    },
    // 零件类型下拉框查询
    getMaterialTypeList() {
      return this.materialTypeList
    },
    getMaterialTypeType(row, column, cellValue) {
      this.materialTypeList.forEach((obj) => {
        if (obj.value == cellValue) {
          cellValue = obj.label
        }
      })
      return cellValue
    }
  }
}
</script>
